#
# spec file for package kalm
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define kf6_version 6.6.0
%define qt6_version 6.6.0

%bcond_without  released
Name:           kalm
Version:        24.12.3
Release:        1.1
Summary:        Breathing techniques helper
License:        LGPL-2.1-or-later
URL:            https://apps.kde.org/kalm
Source0:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  kf6-extra-cmake-modules >= %{kf6_version}
BuildRequires:  cmake(KF6Config) >= %{kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{kf6_version}
BuildRequires:  cmake(KF6Crash) >= %{kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{kf6_version}
BuildRequires:  cmake(KF6Kirigami2) >= %{kf6_version}
BuildRequires:  cmake(KF6KirigamiAddons)
BuildRequires:  cmake(KF6QQC2DesktopStyle) >= %{kf6_version}
BuildRequires:  cmake(Qt6Core) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6QuickControls2) >= %{qt6_version}
BuildRequires:  cmake(Qt6Test) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}
Requires:       kf6-kirigami-imports >= %{kf6_version}
Requires:       kf6-qqc2-desktop-style >= %{kf6_version}
Requires:       kirigami-addons6

%description
Kalm can teach you different breathing techniques.

%lang_package

%prep
%autosetup -p1

%build
%cmake_kf6

%kf6_build

%install
%kf6_install

%find_lang %{name} --all-name

%files
%license LICENSES/*
%doc README.md
%{_kf6_applicationsdir}/org.kde.kalm.desktop
%{_kf6_appstreamdir}/org.kde.kalm.appdata.xml
%{_kf6_bindir}/kalm
%{_kf6_iconsdir}/hicolor/scalable/apps/org.kde.kalm.svg

%files lang -f %{name}.lang

%changelog
* Tue Mar  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.3/
- No code change since 24.12.2
* Tue Feb  4 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.2/
- Changes since 24.12.1:
  * Appdata: add display size
  * snapcraft: initial snap packaging
  * Remove unused string from Android manifest
* Tue Jan  7 2025 Christophe Marin <christophe@krop.fr>
- Update to 24.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.1/
- Changes since 24.12.0:
  * Fix Linux CI build for GCC < 14
  * Fix Linux CI build
* Sun Dec  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.12.0/
- No code change since 24.11.90
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.90
  * New feature release
- Changes since 24.11.80:
  * Get qmlformat from Qt CMake files instead of searching for it
* Sat Nov 16 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.11.80
  * New feature release
- Changes since 24.08.3:
  * Add option self-test and corresponding autotest
  * Add autotests
  * Appdata: fix developer
  * Fix instruction text cut off on small screens
  * Build Android APKs
  * Save window state
* Tue Nov  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.3/
- No code change since 24.08.2
* Tue Oct  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.2/
- No code change since 24.08.1
* Tue Sep 10 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.1/
- No code change since 24.08.0
* Mon Aug 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.08.0/
- Changes since 24.05.2:
  * Flatpak: update Kirigami Addons to 1.3.0
  * Flatpak: move cleanup to top level
  * Use singleton instead of context property for settings
  * Port settings to FormCard
  * Move info button to the toolbar
  * Add titles for breathing pages
  * Port away from OverlaySheet
  * Run latest qmlformat
  * Don't use context property to expose AboutData to qml
  * Flatpak: update Kirigami Addons to 1.2.1
  * Fix Appstream for new release
  * Add 24.05.0 release description
* Tue Jul  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.2/
- No code change since 24.05.1
* Wed Jun 12 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.1/
- Changes since 24.05.0:
  * Fix Appstream for new release
* Sun May 19 2024 Christophe Marin <christophe@krop.fr>
- Update to 24.05.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/24.05.0/
- No code change since 24.04.80
* Fri May  3 2024 Christophe Marin <christophe@krop.fr>
- Init kalm
